Phase1Output

Struct Phase1Output 

pub struct Phase1Output<F: PrimeField> {
    pub id: ParticipantId,
    pub batch_size: u32,
    pub r: Vec<F>,
    pub e: Vec<F>,
    pub masked_signing_key_shares: Vec<F>,
    pub masked_rs: Vec<F>,
    pub others: Vec<ParticipantId>,
}
The length of vectors r, e, masked_signing_key_shares, masked_rs should be batch_size as each item of the vector corresponds to 1 signature

Fields

id: ParticipantIdbatch_size: u32r: Vec<F>

Shares of the random r, one share for each item in the batch

e: Vec<F>masked_signing_key_shares: Vec<F>

Additive shares of the signing key masked by a random alpha

masked_rs: Vec<F>

Additive shares of r masked by a random beta

others: Vec<ParticipantId>