pub struct Phase1Output<F: PrimeField> {
pub id: ParticipantId,
pub batch_size: u32,
pub r: Vec<F>,
pub e: Vec<F>,
pub masked_signing_key_shares: Vec<F>,
pub masked_rs: Vec<F>,
pub others: Vec<ParticipantId>,
}Expand description
The length of vectors r, e, masked_signing_key_shares, masked_rs should
be batch_size as each item of the vector corresponds to 1 signature
Fields
id: ParticipantIdbatch_size: u32r: Vec<F>Shares of the random r, one share for each item in the batch
e: Vec<F>Additive shares of the signing key masked by a random alpha
masked_rs: Vec<F>Additive shares of r masked by a random beta
others: Vec<ParticipantId>Trait Implementations
Sourceimpl<F: PrimeField> CanonicalDeserialize for Phase1Output<F>
impl<F: PrimeField> CanonicalDeserialize for Phase1Output<F>
Sourcefn deserialize_with_mode<R: Read>(
reader: R,
compress: Compress,
validate: Validate,
) -> Result<Self, SerializationError>
fn deserialize_with_mode<R: Read>( reader: R, compress: Compress, validate: Validate, ) -> Result<Self, SerializationError>
The general deserialize method that takes in customization flags.
fn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Sourceimpl<F: PrimeField> CanonicalSerialize for Phase1Output<F>
impl<F: PrimeField> CanonicalSerialize for Phase1Output<F>
Sourcefn serialize_with_mode<W: Write>(
&self,
writer: W,
compress: Compress,
) -> Result<(), SerializationError>
fn serialize_with_mode<W: Write>( &self, writer: W, compress: Compress, ) -> Result<(), SerializationError>
The general serialize method that takes in customization flags.
fn serialized_size(&self, compress: Compress) -> usize
fn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn compressed_size(&self) -> usize
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn uncompressed_size(&self) -> usize
Sourceimpl<F: Clone + PrimeField> Clone for Phase1Output<F>
impl<F: Clone + PrimeField> Clone for Phase1Output<F>
Sourcefn clone(&self) -> Phase1Output<F>
fn clone(&self) -> Phase1Output<F>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<F: Debug + PrimeField> Debug for Phase1Output<F>
impl<F: Debug + PrimeField> Debug for Phase1Output<F>
Sourceimpl<F: PartialEq + PrimeField> PartialEq for Phase1Output<F>
impl<F: PartialEq + PrimeField> PartialEq for Phase1Output<F>
impl<F: PartialEq + PrimeField> StructuralPartialEq for Phase1Output<F>
Sourceimpl<F: PrimeField> Valid for Phase1Output<F>
impl<F: PrimeField> Valid for Phase1Output<F>
fn check(&self) -> Result<(), SerializationError>
fn batch_check<'a>(
batch: impl Iterator<Item = &'a Self> + Send,
) -> Result<(), SerializationError>where
Self: 'a,